package org.punkcraft.longerday;

import com.google.inject.Inject;
import org.slf4j.Logger;
import org.spongepowered.api.Sponge;
import org.spongepowered.api.scheduler.Task;
import org.spongepowered.api.world.World;
import org.spongepowered.api.event.Listener;
import org.spongepowered.api.event.game.state.GameStartedServerEvent;
import org.spongepowered.api.plugin.Plugin;

import java.util.Optional;

@Plugin(id = "longerday", name = "LongerDay", version = "1.0", description = "Extends the day cycle")
public class LongerDay {

    @Inject
    private Logger logger;

    private int timeCounter = 0;

    @Listener
    public void onServerStart(GameStartedServerEvent event) {
        logger.info("Successfully running LongerDay");

        // Получаем первый мир (обычно это "world")
        Optional<World> worldOptional = Sponge.getServer().getWorlds().stream().findFirst();
        if (!worldOptional.isPresent()) {
            logger.error("No worlds found! Unable to set game rules.");
            return;
        }

        World world = worldOptional.get();


        // Запускаем задачу для изменения времени каждые 5 тиков
        Task.builder()
                .intervalTicks(5) // Выполняется каждые 5 тиков
                .execute(() -> {
                    try {
                        // Изменяем время в мире
                        timeCounter = (timeCounter + 1) % 24000; // Циклический счетчик времени
                        world.getProperties().setWorldTime((long) timeCounter); // Устанавливаем новое время
                        logger.debug("Time set to: {} in world: {}", timeCounter, world.getName());
                    } catch (Exception e) {
                        logger.error("Error while setting world time: ", e);
                    }
                })
                .submit(this); // Подаем задачу в планировщик
    }

    public Logger getLogger() {
        return logger;
    }
}
